tonalitytools.make_first_n_notes_in_ascending_diatonic_scale
============================================================

.. autofunction:: abjad.tools.tonalitytools.make_first_n_notes_in_ascending_diatonic_scale.make_first_n_notes_in_ascending_diatonic_scale
